AppLovin class
Constructors
Properties
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interestialId ↔ String?
-
getter/setter pair
- isBannerAds ↔ bool?
-
getter/setter pair
- isInterstitialAds ↔ bool?
-
getter/setter pair
- isNativeAds ↔ bool?
-
getter/setter pair
- isOpenAds ↔ bool?
-
getter/setter pair
- isRewaredAds ↔ bool?
-
getter/setter pair
- isUnlimitedAds ↔ bool?
-
getter/setter pair
- nativeAds ↔ AppLovinNative?
-
getter/setter pair
- openId ↔ String?
-
getter/setter pair
- rewaredId ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkKey ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited