FacebookAds class

Constructors

FacebookAds({String? bannerId, String? interestialId, String? rewardedId, String? nativeId, bool? isBannerAds, bool? isInterstitialAds, bool? isRewaredAds, bool? isNativeAds, int? interstitialInterval})
FacebookAds.fromJson(Map<String, dynamic> json)

Properties

bannerId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interestialId String?
getter/setter pair
interstitialInterval int?
getter/setter pair
isBannerAds bool?
getter/setter pair
isInterstitialAds bool?
getter/setter pair
isNativeAds bool?
getter/setter pair
isRewaredAds bool?
getter/setter pair
nativeId String?
getter/setter pair
rewardedId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited